unit JvInterpreter_ZFiles;

{$I jvcl.inc}

interface

uses
  SysUtils,
  {$IFDEF UNITVERSIONING}
  JclUnitVersioning,
  {$ENDIF UNITVERSIONING}
  Classes,
  JvInterpreter,
  JvSelectDirectory;

procedure RegisterJvInterpreterAdapter(JvInterpreterAdapter: TJvInterpreterAdapter);

{$IFDEF UNITVERSIONING}
//const
//  UnitVersioning: TUnitVersionInfo = (
//    RCSfile: '$URL: https://jvcl.svn.sourceforge.net/svnroot/jvcl/branches/JVCL3_30_PREPARATION/run/JvInterpreter_Dialogs.pas $';
//    Revision: '$Revision: 10612 $';
//    Date: '$Date: 2006-05-19 21:04:09 +0200 (ven., 19 mai 2006) $';
//    LogPath: 'JVCL\run'
//  );
{$ENDIF UNITVERSIONING}

implementation

uses Dialogs;

procedure JvInterpreter_FileToStr(var Value: Variant; Args: TJvInterpreterArgs);
var
  F, Len: Integer;
  Str: PChar;
begin
  F := FileOpen(Args.Values[0], fmOpenRead + fmShareDenyNone);
  if F = -1 then
    Exit;
  try
    Len := FileSeek(F, 0, 2);
    Str := StrAlloc(Len);
    FileSeek(F, 0, 0);
    Len := FileRead(F, Str^, Len);
    Value := String(Str);
  finally
    StrDispose(Str);
    FileClose(F);
  end;
end;

procedure JvInterpreter_DirectoryExists(var Value: Variant; Args: TJvInterpreterArgs);
begin
  Value := DirectoryExists(Args.Values[0]);
end;

procedure TJvSelectDirectory_Create(var Value: Variant; Args: TJvInterpreterArgs);
begin
  Value := O2V(TJvSelectDirectory.Create(V2O(Args.Values[0]) as TComponent));
end;

procedure TJvSelectDirectory_Execute(var Value: Variant; Args: TJvInterpreterArgs);
begin
  Value := TJvSelectDirectory(Args.Obj).Execute;
end;

procedure TJvSelectDirectory_Read_Directory(var Value: Variant; Args: TJvInterpreterArgs);
begin
  Value := (V2O(Args.Values[0]) as TJvSelectDirectory).Directory;
end;

procedure TJvSelectDirectory_Read_InitialDir(var Value: Variant; Args: TJvInterpreterArgs);
begin
  Value := TJvSelectDirectory(Args.Obj).InitialDir;
end;

procedure TJvSelectDirectory_Write_InitialDir(const Value: Variant; Args: TJvInterpreterArgs);
begin
  TJvSelectDirectory(Args.Obj).InitialDir := Value;
end;

procedure TJvSelectDirectory_Read_ClassicDialog(var Value: Variant; Args: TJvInterpreterArgs);
begin
  Value := TJvSelectDirectory(Args.Obj).ClassicDialog;
end;

procedure TJvSelectDirectory_Write_ClassicDialog(const Value: Variant; Args: TJvInterpreterArgs);
begin
  TJvSelectDirectory(Args.Obj).ClassicDialog := Value;
end;

procedure TJvSelectDirectory_Read_Title(var Value: Variant; Args: TJvInterpreterArgs);
begin
  Value := TJvSelectDirectory(Args.Obj).Title;
end;

procedure TJvSelectDirectory_Write_Title(const Value: Variant; Args: TJvInterpreterArgs);
begin
  TJvSelectDirectory(Args.Obj).Title := Value;
end;

procedure TJvSelectDirectory_Read_Handle(var Value: Variant; Args: TJvInterpreterArgs);
begin
  Value := TJvSelectDirectory(Args.Obj).Handle;
end;

procedure TJvSelectDirectory_Read_Ctl3D(var Value: Variant; Args: TJvInterpreterArgs);
begin
  Value := TJvSelectDirectory(Args.Obj).Ctl3D;
end;

procedure TJvSelectDirectory_Write_Ctl3D(const Value: Variant; Args: TJvInterpreterArgs);
begin
  TJvSelectDirectory(Args.Obj).Ctl3D := Value;
end;

procedure RegisterJvInterpreterAdapter(JvInterpreterAdapter: TJvInterpreterAdapter);
const
  cSystem = 'ZFiles';
begin
  with JvInterpreterAdapter do
    begin
      AddFunction(cSystem, 'FileToStr', JvInterpreter_FileToStr, 1, [varEmpty], varEmpty);
      AddFunction(cSystem, 'DirectoryExists', JvInterpreter_DirectoryExists, 1, [varEmpty], varEmpty);

      AddClass(cSystem, TJvSelectDirectory, 'TJvSelectDirectory');
      AddGet(TJvSelectDirectory, 'Create', TJvSelectDirectory_Create, 1, [varEmpty], varEmpty);
      AddGet(TJvSelectDirectory, 'Execute', TJvSelectDirectory_Execute, 0, [varEmpty], varEmpty);
      AddGet(TJvSelectDirectory, 'Directory', TJvSelectDirectory_Read_Directory, 0, [varEmpty], varEmpty);
      AddGet(TJvSelectDirectory, 'Handle', TJvSelectDirectory_Read_Handle, 0, [varEmpty], varEmpty);

      AddGet(TJvSelectDirectory, 'InitialDir', TJvSelectDirectory_Read_InitialDir, 0, [varEmpty], varEmpty);
      AddSet(TJvSelectDirectory, 'InitialDir', TJvSelectDirectory_Write_InitialDir, 0, [varEmpty]);
      AddGet(TJvSelectDirectory, 'ClassicDialog', TJvSelectDirectory_Read_ClassicDialog, 0, [varEmpty], varEmpty);
      AddSet(TJvSelectDirectory, 'ClassicDialog', TJvSelectDirectory_Write_ClassicDialog, 0, [varEmpty]);
      AddGet(TJvSelectDirectory, 'Title', TJvSelectDirectory_Read_Title, 0, [varEmpty], varEmpty);
      AddSet(TJvSelectDirectory, 'Title', TJvSelectDirectory_Write_Title, 0, [varEmpty]);
      AddGet(TJvSelectDirectory, 'Ctl3D', TJvSelectDirectory_Read_Ctl3D, 0, [varEmpty], varEmpty);
      AddSet(TJvSelectDirectory, 'Ctl3D', TJvSelectDirectory_Write_Ctl3D, 0, [varEmpty]);
    end;
end;

{$IFDEF UNITVERSIONING}
initialization
  RegisterUnitVersion(HInstance, UnitVersioning);

finalization
  UnregisterUnitVersion(HInstance);
{$ENDIF UNITVERSIONING}

end.
